# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/user_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/user_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.organizationmanager.v1.idp import user_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/organizationmanager/v1/idp/user_service.proto\x12\'yandex.cloud.organizationmanager.v1.idp\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x32yandex/cloud/organizationmanager/v1/idp/user.proto\x1a\x1dyandex/cloud/validation.proto\"/\n\x0eGetUserRequest\x12\x1d\n\x07user_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x10ListUsersRequest\x12!\n\x0buserpool_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"j\n\x11ListUsersResponse\x12<\n\x05users\x18\x01 \x03(\x0b\x32-.yandex.cloud.organizationmanager.v1.idp.User\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xad\x04\n\x11\x43reateUserRequest\x12!\n\x0buserpool_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x41\n\x08username\x18\x02 \x01(\tB/\xe8\xc7\x31\x01\xf2\xc7\x31\x1e[a-z0-9A-Z\\._-]{1,64}@.{1,256}\x8a\xc8\x31\x05<=254\x12 \n\tfull_name\x18\x04 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=256\x12\x1d\n\ngiven_name\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x1e\n\x0b\x66\x61mily_name\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\'\n\x05\x65mail\x18\x07 \x01(\tB\x18\xf2\xc7\x31\x0b|(.{3,254})\x8a\xc8\x31\x05<=254\x12\x1e\n\x0cphone_number\x18\x08 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12N\n\rpassword_spec\x18\t \x01(\x0b\x32\x35.yandex.cloud.organizationmanager.v1.idp.PasswordSpecH\x00\x12N\n\rpassword_hash\x18\x0b \x01(\x0b\x32\x35.yandex.cloud.organizationmanager.v1.idp.PasswordHashH\x00\x12-\n\tis_active\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1e\n\x0b\x65xternal_id\x18\x0c \x01(\tB\t\x8a\xc8\x31\x05<=256B\x13\n\x0b\x63redentials\x12\x04\xc0\xc1\x31\x01J\x04\x08\x03\x10\x04\"%\n\x12\x43reateUserMetadata\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"\xcf\x02\n\x11UpdateUserRequest\x12\x1d\n\x07user_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12>\n\x08username\x18\x03 \x01(\tB,\xf2\xc7\x31\x1f|[a-z0-9A-Z\\._-]{1,64}@.{1,256}\x8a\xc8\x31\x05<=254\x12\x1c\n\tfull_name\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x1d\n\ngiven_name\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x1e\n\x0b\x66\x61mily_name\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\'\n\x05\x65mail\x18\x08 \x01(\tB\x18\xf2\xc7\x31\x0b|(.{3,254})\x8a\xc8\x31\x05<=254\x12\x1e\n\x0cphone_number\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50J\x04\x08\x04\x10\x05\"%\n\x12UpdateUserMetadata\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"2\n\x11\x44\x65leteUserRequest\x12\x1d\n\x07user_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"%\n\x12\x44\x65leteUserMetadata\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"R\n\x12SuspendUserRequest\x12\x1d\n\x07user_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x06reason\x18\x02 \x01(\tB\r\xe8\xc7\x31\x00\x8a\xc8\x31\x05<=256\"&\n\x13SuspendUserMetadata\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"6\n\x15ReactivateUserRequest\x12\x1d\n\x07user_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x16ReactivateUserMetadata\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"\x90\x01\n\x15SetOwnPasswordRequest\x12R\n\rpassword_spec\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.organizationmanager.v1.idp.PasswordSpecB\x04\xe8\xc7\x31\x01\x12#\n\x0cold_password\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=128\")\n\x16SetOwnPasswordMetadata\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"\x18\n\x16SetOwnPasswordResponse\"\x8d\x01\n\x18SetOthersPasswordRequest\x12\x1d\n\x07user_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12R\n\rpassword_spec\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.organizationmanager.v1.idp.PasswordSpecB\x04\xe8\xc7\x31\x01\",\n\x19SetOthersPasswordMetadata\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"\x1b\n\x19SetOthersPasswordResponse\"\x19\n\x17GeneratePasswordRequest\"h\n\x18GeneratePasswordResponse\x12L\n\rpassword_spec\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.organizationmanager.v1.idp.PasswordSpec\"T\n\x0cPasswordSpec\x12\x1f\n\x08password\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=128\x12#\n\x10generation_proof\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=128\"\xd0\x03\n\x10PasswordMetadata\x12\n\n\x02id\x18\x01 \x01(\t\x12T\n\x04type\x18\x02 \x01(\x0e\x32\x46.yandex.cloud.organizationmanager.v1.idp.PasswordMetadata.PasswordType\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12[\n\nlast_usage\x18\x05 \x01(\x0b\x32G.yandex.cloud.organizationmanager.v1.idp.PasswordMetadata.PasswordUsage\x1aP\n\rPasswordUsage\x12+\n\x07used_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nip_address\x18\x02 \x01(\t\"K\n\x0cPasswordType\x12\x1d\n\x19PASSWORD_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tTEMPORARY\x10\x01\x12\r\n\tPERMANENT\x10\x02\"a\n\x1c\x43onvertToExternalUserRequest\x12\x1d\n\x07user_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\"\n\x0b\x65xternal_id\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=256\"E\n\x1d\x43onvertToExternalUserMetadata\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x02 \x01(\t\"|\n\x16SetPasswordHashRequest\x12\x1d\n\x07user_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x43\n\x04hash\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.organizationmanager.v1.idp.PasswordHash\"*\n\x17SetPasswordHashMetadata\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"\xe2\x01\n\x0cPasswordHash\x12$\n\rpassword_hash\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=128\x12h\n\x12password_hash_type\x18\x02 \x01(\x0e\x32\x46.yandex.cloud.organizationmanager.v1.idp.PasswordHash.PasswordHashTypeB\x04\xe8\xc7\x31\x01\"B\n\x10PasswordHashType\x12\"\n\x1ePASSWORD_HASH_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x44_MD4\x10\x01\"i\n\x19ResolveExternalIdsRequest\x12!\n\x0buserpool_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12)\n\x0c\x65xternal_ids\x18\x02 \x03(\tB\x13\x82\xc8\x31\x06\x31-1000\x8a\xc8\x31\x05<=256\"I\n\x0cResolvedUser\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x02 \x01(\t\x12\x13\n\x0buserpool_id\x18\x03 \x01(\t\"k\n\x1aResolveExternalIdsResponse\x12M\n\x0eresolved_users\x18\x01 \x03(\x0b\x32\x35.yandex.cloud.organizationmanager.v1.idp.ResolvedUser2\xae\x17\n\x0bUserService\x12\xa3\x01\n\x03Get\x12\x37.yandex.cloud.organizationmanager.v1.idp.GetUserRequest\x1a-.yandex.cloud.organizationmanager.v1.idp.User\"4\x82\xd3\xe4\x93\x02.\x12,/organization-manager/v1/idp/users/{user_id}\x12\xa9\x01\n\x04List\x12\x39.yandex.cloud.organizationmanager.v1.idp.ListUsersRequest\x1a:.yandex.cloud.organizationmanager.v1.idp.ListUsersResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/organization-manager/v1/idp/users\x12\xb4\x01\n\x06\x43reate\x12:.yandex.cloud.organizationmanager.v1.idp.CreateUserRequest\x1a!.yandex.cloud.operation.Operation\"K\xb2\xd2*\x1a\n\x12\x43reateUserMetadata\x12\x04User\x82\xd3\xe4\x93\x02\'\"\"/organization-manager/v1/idp/users:\x01*\x12\xbe\x01\n\x06Update\x12:.yandex.cloud.organizationmanager.v1.idp.UpdateUserRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*\x1a\n\x12UpdateUserMetadata\x12\x04User\x82\xd3\xe4\x93\x02\x31\x32,/organization-manager/v1/idp/users/{user_id}:\x01*\x12\xcc\x01\n\x06\x44\x65lete\x12:.yandex.cloud.organizationmanager.v1.idp.DeleteUserRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*+\n\x12\x44\x65leteUserMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02.*,/organization-manager/v1/idp/users/{user_id}\x12\xe5\x01\n\x0eSetOwnPassword\x12>.yandex.cloud.organizationmanager.v1.idp.SetOwnPasswordRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*0\n\x16SetOwnPasswordMetadata\x12\x16SetOwnPasswordResponse\x82\xd3\xe4\x93\x02\x36\"1/organization-manager/v1/idp/users:setOwnPassword:\x01*\x12\xff\x01\n\x11SetOthersPassword\x12\x41.yandex.cloud.organizationmanager.v1.idp.SetOthersPasswordRequest\x1a!.yandex.cloud.operation.Operation\"\x83\x01\xb2\xd2*6\n\x19SetOthersPasswordMetadata\x12\x19SetOthersPasswordResponse\x82\xd3\xe4\x93\x02\x43\">/organization-manager/v1/idp/users/{user_id}:setOthersPassword:\x01*\x12\xda\x01\n\x07Suspend\x12;.yandex.cloud.organizationmanager.v1.idp.SuspendUserRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*,\n\x13SuspendUserMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x39\"4/organization-manager/v1/idp/users/{user_id}:suspend:\x01*\x12\xe6\x01\n\nReactivate\x12>.yandex.cloud.organizationmanager.v1.idp.ReactivateUserRequest\x1a!.yandex.cloud.operation.Operation\"u\xb2\xd2*/\n\x16ReactivateUserMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02<\"7/organization-manager/v1/idp/users/{user_id}:reactivate:\x01*\x12\xd7\x01\n\x10GeneratePassword\x12@.yandex.cloud.organizationmanager.v1.idp.GeneratePasswordRequest\x1a\x41.yandex.cloud.organizationmanager.v1.idp.GeneratePasswordResponse\">\x82\xd3\xe4\x93\x02\x38\"3/organization-manager/v1/idp/users:generatePassword:\x01*\x12\xb0\x01\n\x17GetSelfPasswordMetadata\x12\x16.google.protobuf.Empty\x1a\x39.yandex.cloud.organizationmanager.v1.idp.PasswordMetadata\"B\x82\xd3\xe4\x93\x02<\x12:/organization-manager/v1/idp/users:getSelfPasswordMetadata\x12\xf1\x01\n\x11\x43onvertToExternal\x12\x45.yandex.cloud.organizationmanager.v1.idp.ConvertToExternalUserRequest\x1a!.yandex.cloud.operation.Operation\"r\xb2\xd2*%\n\x1d\x43onvertToExternalUserMetadata\x12\x04User\x82\xd3\xe4\x93\x02\x43\">/organization-manager/v1/idp/users/{user_id}:convertToExternal:\x01*\x12\xf2\x01\n\x0fSetPasswordHash\x12?.yandex.cloud.organizationmanager.v1.idp.SetPasswordHashRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*0\n\x17SetPasswordHashMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x41\"</organization-manager/v1/idp/users/{user_id}:setPasswordHash:\x01*\x12\xdf\x01\n\x12ResolveExternalIds\x12\x42.yandex.cloud.organizationmanager.v1.idp.ResolveExternalIdsRequest\x1a\x43.yandex.cloud.organizationmanager.v1.idp.ResolveExternalIdsResponse\"@\x82\xd3\xe4\x93\x02:\"5/organization-manager/v1/idp/users:resolveExternalIds:\x01*B~\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idpb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.user_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idp'
  _globals['_GETUSERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_GETUSERREQUEST'].fields_by_name['user_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTUSERSREQUEST'].fields_by_name['userpool_id']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['userpool_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTUSERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATEUSERREQUEST'].oneofs_by_name['credentials']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].oneofs_by_name['credentials']._serialized_options = b'\300\3011\001'
  _globals['_CREATEUSERREQUEST'].fields_by_name['userpool_id']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['userpool_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEUSERREQUEST'].fields_by_name['username']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['username']._serialized_options = b'\350\3071\001\362\3071\036[a-z0-9A-Z\\._-]{1,64}@.{1,256}\212\3101\005<=254'
  _globals['_CREATEUSERREQUEST'].fields_by_name['full_name']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['full_name']._serialized_options = b'\350\3071\001\212\3101\005<=256'
  _globals['_CREATEUSERREQUEST'].fields_by_name['given_name']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['given_name']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEUSERREQUEST'].fields_by_name['family_name']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['family_name']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEUSERREQUEST'].fields_by_name['email']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['email']._serialized_options = b'\362\3071\013|(.{3,254})\212\3101\005<=254'
  _globals['_CREATEUSERREQUEST'].fields_by_name['phone_number']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['phone_number']._serialized_options = b'\212\3101\004<=50'
  _globals['_CREATEUSERREQUEST'].fields_by_name['external_id']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['external_id']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['username']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['username']._serialized_options = b'\362\3071\037|[a-z0-9A-Z\\._-]{1,64}@.{1,256}\212\3101\005<=254'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['full_name']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['full_name']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['given_name']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['given_name']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['family_name']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['family_name']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['email']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['email']._serialized_options = b'\362\3071\013|(.{3,254})\212\3101\005<=254'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['phone_number']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['phone_number']._serialized_options = b'\212\3101\004<=50'
  _globals['_DELETEUSERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_DELETEUSERREQUEST'].fields_by_name['user_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SUSPENDUSERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_SUSPENDUSERREQUEST'].fields_by_name['user_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SUSPENDUSERREQUEST'].fields_by_name['reason']._loaded_options = None
  _globals['_SUSPENDUSERREQUEST'].fields_by_name['reason']._serialized_options = b'\350\3071\000\212\3101\005<=256'
  _globals['_REACTIVATEUSERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_REACTIVATEUSERREQUEST'].fields_by_name['user_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SETOWNPASSWORDREQUEST'].fields_by_name['password_spec']._loaded_options = None
  _globals['_SETOWNPASSWORDREQUEST'].fields_by_name['password_spec']._serialized_options = b'\350\3071\001'
  _globals['_SETOWNPASSWORDREQUEST'].fields_by_name['old_password']._loaded_options = None
  _globals['_SETOWNPASSWORDREQUEST'].fields_by_name['old_password']._serialized_options = b'\350\3071\001\212\3101\005<=128'
  _globals['_SETOTHERSPASSWORDREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_SETOTHERSPASSWORDREQUEST'].fields_by_name['user_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SETOTHERSPASSWORDREQUEST'].fields_by_name['password_spec']._loaded_options = None
  _globals['_SETOTHERSPASSWORDREQUEST'].fields_by_name['password_spec']._serialized_options = b'\350\3071\001'
  _globals['_PASSWORDSPEC'].fields_by_name['password']._loaded_options = None
  _globals['_PASSWORDSPEC'].fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\005<=128'
  _globals['_PASSWORDSPEC'].fields_by_name['generation_proof']._loaded_options = None
  _globals['_PASSWORDSPEC'].fields_by_name['generation_proof']._serialized_options = b'\212\3101\005<=128'
  _globals['_CONVERTTOEXTERNALUSERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_CONVERTTOEXTERNALUSERREQUEST'].fields_by_name['user_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CONVERTTOEXTERNALUSERREQUEST'].fields_by_name['external_id']._loaded_options = None
  _globals['_CONVERTTOEXTERNALUSERREQUEST'].fields_by_name['external_id']._serialized_options = b'\350\3071\001\212\3101\005<=256'
  _globals['_SETPASSWORDHASHREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_SETPASSWORDHASHREQUEST'].fields_by_name['user_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PASSWORDHASH'].fields_by_name['password_hash']._loaded_options = None
  _globals['_PASSWORDHASH'].fields_by_name['password_hash']._serialized_options = b'\350\3071\001\212\3101\005<=128'
  _globals['_PASSWORDHASH'].fields_by_name['password_hash_type']._loaded_options = None
  _globals['_PASSWORDHASH'].fields_by_name['password_hash_type']._serialized_options = b'\350\3071\001'
  _globals['_RESOLVEEXTERNALIDSREQUEST'].fields_by_name['userpool_id']._loaded_options = None
  _globals['_RESOLVEEXTERNALIDSREQUEST'].fields_by_name['userpool_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESOLVEEXTERNALIDSREQUEST'].fields_by_name['external_ids']._loaded_options = None
  _globals['_RESOLVEEXTERNALIDSREQUEST'].fields_by_name['external_ids']._serialized_options = b'\202\3101\0061-1000\212\3101\005<=256'
  _globals['_USERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002.\022,/organization-manager/v1/idp/users/{user_id}'
  _globals['_USERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002$\022\"/organization-manager/v1/idp/users'
  _globals['_USERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\032\n\022CreateUserMetadata\022\004User\202\323\344\223\002\'\"\"/organization-manager/v1/idp/users:\001*'
  _globals['_USERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\032\n\022UpdateUserMetadata\022\004User\202\323\344\223\00212,/organization-manager/v1/idp/users/{user_id}:\001*'
  _globals['_USERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*+\n\022DeleteUserMetadata\022\025google.protobuf.Empty\202\323\344\223\002.*,/organization-manager/v1/idp/users/{user_id}'
  _globals['_USERSERVICE'].methods_by_name['SetOwnPassword']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['SetOwnPassword']._serialized_options = b'\262\322*0\n\026SetOwnPasswordMetadata\022\026SetOwnPasswordResponse\202\323\344\223\0026\"1/organization-manager/v1/idp/users:setOwnPassword:\001*'
  _globals['_USERSERVICE'].methods_by_name['SetOthersPassword']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['SetOthersPassword']._serialized_options = b'\262\322*6\n\031SetOthersPasswordMetadata\022\031SetOthersPasswordResponse\202\323\344\223\002C\">/organization-manager/v1/idp/users/{user_id}:setOthersPassword:\001*'
  _globals['_USERSERVICE'].methods_by_name['Suspend']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Suspend']._serialized_options = b'\262\322*,\n\023SuspendUserMetadata\022\025google.protobuf.Empty\202\323\344\223\0029\"4/organization-manager/v1/idp/users/{user_id}:suspend:\001*'
  _globals['_USERSERVICE'].methods_by_name['Reactivate']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Reactivate']._serialized_options = b'\262\322*/\n\026ReactivateUserMetadata\022\025google.protobuf.Empty\202\323\344\223\002<\"7/organization-manager/v1/idp/users/{user_id}:reactivate:\001*'
  _globals['_USERSERVICE'].methods_by_name['GeneratePassword']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['GeneratePassword']._serialized_options = b'\202\323\344\223\0028\"3/organization-manager/v1/idp/users:generatePassword:\001*'
  _globals['_USERSERVICE'].methods_by_name['GetSelfPasswordMetadata']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['GetSelfPasswordMetadata']._serialized_options = b'\202\323\344\223\002<\022:/organization-manager/v1/idp/users:getSelfPasswordMetadata'
  _globals['_USERSERVICE'].methods_by_name['ConvertToExternal']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['ConvertToExternal']._serialized_options = b'\262\322*%\n\035ConvertToExternalUserMetadata\022\004User\202\323\344\223\002C\">/organization-manager/v1/idp/users/{user_id}:convertToExternal:\001*'
  _globals['_USERSERVICE'].methods_by_name['SetPasswordHash']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['SetPasswordHash']._serialized_options = b'\262\322*0\n\027SetPasswordHashMetadata\022\025google.protobuf.Empty\202\323\344\223\002A\"</organization-manager/v1/idp/users/{user_id}:setPasswordHash:\001*'
  _globals['_USERSERVICE'].methods_by_name['ResolveExternalIds']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['ResolveExternalIds']._serialized_options = b'\202\323\344\223\002:\"5/organization-manager/v1/idp/users:resolveExternalIds:\001*'
  _globals['_GETUSERREQUEST']._serialized_start=418
  _globals['_GETUSERREQUEST']._serialized_end=465
  _globals['_LISTUSERSREQUEST']._serialized_start=468
  _globals['_LISTUSERSREQUEST']._serialized_end=612
  _globals['_LISTUSERSRESPONSE']._serialized_start=614
  _globals['_LISTUSERSRESPONSE']._serialized_end=720
  _globals['_CREATEUSERREQUEST']._serialized_start=723
  _globals['_CREATEUSERREQUEST']._serialized_end=1280
  _globals['_CREATEUSERMETADATA']._serialized_start=1282
  _globals['_CREATEUSERMETADATA']._serialized_end=1319
  _globals['_UPDATEUSERREQUEST']._serialized_start=1322
  _globals['_UPDATEUSERREQUEST']._serialized_end=1657
  _globals['_UPDATEUSERMETADATA']._serialized_start=1659
  _globals['_UPDATEUSERMETADATA']._serialized_end=1696
  _globals['_DELETEUSERREQUEST']._serialized_start=1698
  _globals['_DELETEUSERREQUEST']._serialized_end=1748
  _globals['_DELETEUSERMETADATA']._serialized_start=1750
  _globals['_DELETEUSERMETADATA']._serialized_end=1787
  _globals['_SUSPENDUSERREQUEST']._serialized_start=1789
  _globals['_SUSPENDUSERREQUEST']._serialized_end=1871
  _globals['_SUSPENDUSERMETADATA']._serialized_start=1873
  _globals['_SUSPENDUSERMETADATA']._serialized_end=1911
  _globals['_REACTIVATEUSERREQUEST']._serialized_start=1913
  _globals['_REACTIVATEUSERREQUEST']._serialized_end=1967
  _globals['_REACTIVATEUSERMETADATA']._serialized_start=1969
  _globals['_REACTIVATEUSERMETADATA']._serialized_end=2010
  _globals['_SETOWNPASSWORDREQUEST']._serialized_start=2013
  _globals['_SETOWNPASSWORDREQUEST']._serialized_end=2157
  _globals['_SETOWNPASSWORDMETADATA']._serialized_start=2159
  _globals['_SETOWNPASSWORDMETADATA']._serialized_end=2200
  _globals['_SETOWNPASSWORDRESPONSE']._serialized_start=2202
  _globals['_SETOWNPASSWORDRESPONSE']._serialized_end=2226
  _globals['_SETOTHERSPASSWORDREQUEST']._serialized_start=2229
  _globals['_SETOTHERSPASSWORDREQUEST']._serialized_end=2370
  _globals['_SETOTHERSPASSWORDMETADATA']._serialized_start=2372
  _globals['_SETOTHERSPASSWORDMETADATA']._serialized_end=2416
  _globals['_SETOTHERSPASSWORDRESPONSE']._serialized_start=2418
  _globals['_SETOTHERSPASSWORDRESPONSE']._serialized_end=2445
  _globals['_GENERATEPASSWORDREQUEST']._serialized_start=2447
  _globals['_GENERATEPASSWORDREQUEST']._serialized_end=2472
  _globals['_GENERATEPASSWORDRESPONSE']._serialized_start=2474
  _globals['_GENERATEPASSWORDRESPONSE']._serialized_end=2578
  _globals['_PASSWORDSPEC']._serialized_start=2580
  _globals['_PASSWORDSPEC']._serialized_end=2664
  _globals['_PASSWORDMETADATA']._serialized_start=2667
  _globals['_PASSWORDMETADATA']._serialized_end=3131
  _globals['_PASSWORDMETADATA_PASSWORDUSAGE']._serialized_start=2974
  _globals['_PASSWORDMETADATA_PASSWORDUSAGE']._serialized_end=3054
  _globals['_PASSWORDMETADATA_PASSWORDTYPE']._serialized_start=3056
  _globals['_PASSWORDMETADATA_PASSWORDTYPE']._serialized_end=3131
  _globals['_CONVERTTOEXTERNALUSERREQUEST']._serialized_start=3133
  _globals['_CONVERTTOEXTERNALUSERREQUEST']._serialized_end=3230
  _globals['_CONVERTTOEXTERNALUSERMETADATA']._serialized_start=3232
  _globals['_CONVERTTOEXTERNALUSERMETADATA']._serialized_end=3301
  _globals['_SETPASSWORDHASHREQUEST']._serialized_start=3303
  _globals['_SETPASSWORDHASHREQUEST']._serialized_end=3427
  _globals['_SETPASSWORDHASHMETADATA']._serialized_start=3429
  _globals['_SETPASSWORDHASHMETADATA']._serialized_end=3471
  _globals['_PASSWORDHASH']._serialized_start=3474
  _globals['_PASSWORDHASH']._serialized_end=3700
  _globals['_PASSWORDHASH_PASSWORDHASHTYPE']._serialized_start=3634
  _globals['_PASSWORDHASH_PASSWORDHASHTYPE']._serialized_end=3700
  _globals['_RESOLVEEXTERNALIDSREQUEST']._serialized_start=3702
  _globals['_RESOLVEEXTERNALIDSREQUEST']._serialized_end=3807
  _globals['_RESOLVEDUSER']._serialized_start=3809
  _globals['_RESOLVEDUSER']._serialized_end=3882
  _globals['_RESOLVEEXTERNALIDSRESPONSE']._serialized_start=3884
  _globals['_RESOLVEEXTERNALIDSRESPONSE']._serialized_end=3991
  _globals['_USERSERVICE']._serialized_start=3994
  _globals['_USERSERVICE']._serialized_end=6984
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/user.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/organizationmanager/v1/idp/user.proto\x12\'yandex.cloud.organizationmanager.v1.idp\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb4\x03\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0buserpool_id\x18\x02 \x01(\t\x12\x44\n\x06status\x18\x03 \x01(\x0e\x32\x34.yandex.cloud.organizationmanager.v1.idp.User.Status\x12\x10\n\x08username\x18\x04 \x01(\t\x12\x11\n\tfull_name\x18\x06 \x01(\t\x12\x12\n\ngiven_name\x18\x07 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x08 \x01(\t\x12\r\n\x05\x65mail\x18\t \x01(\t\x12\x14\n\x0cphone_number\x18\n \x01(\t\x12.\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x65xternal_id\x18\r \x01(\t\"W\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x04\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\r\n\tSUSPENDED\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03J\x04\x08\x05\x10\x06\x42~\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idpb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idp'
  _globals['_USER']._serialized_start=129
  _globals['_USER']._serialized_end=565
  _globals['_USER_STATUS']._serialized_start=472
  _globals['_USER_STATUS']._serialized_end=559
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Userpool(google.protobuf.message.Message):
    """A userpool is a container for users in the Identity Provider system."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Userpool._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Userpool._Status.ValueType  # 0
        """The status is not specified."""
        CREATING: Userpool._Status.ValueType  # 1
        """The userpool is in the process of being created."""
        ACTIVE: Userpool._Status.ValueType  # 2
        """The userpool is active and operational."""
        DELETING: Userpool._Status.ValueType  # 3
        """The userpool is in the process of being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Represents the current status of a userpool."""

    STATUS_UNSPECIFIED: Userpool.Status.ValueType  # 0
    """The status is not specified."""
    CREATING: Userpool.Status.ValueType  # 1
    """The userpool is in the process of being created."""
    ACTIVE: Userpool.Status.ValueType  # 2
    """The userpool is active and operational."""
    DELETING: Userpool.Status.ValueType  # 3
    """The userpool is in the process of being deleted."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    DOMAINS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    USER_SETTINGS_FIELD_NUMBER: builtins.int
    PASSWORD_QUALITY_POLICY_FIELD_NUMBER: builtins.int
    PASSWORD_LIFETIME_POLICY_FIELD_NUMBER: builtins.int
    BRUTEFORCE_PROTECTION_POLICY_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the userpool."""
    organization_id: builtins.str
    """ID of the organization this userpool belongs to."""
    name: builtins.str
    """Name of the userpool."""
    description: builtins.str
    """Description of the userpool."""
    status: global___Userpool.Status.ValueType
    """Current status of the userpool."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as key:value pairs."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the userpool was created."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the userpool was last updated."""

    @property
    def domains(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of domains associated with this userpool."""

    @property
    def user_settings(self) -> global___UserSettings:
        """User settings for this userpool."""

    @property
    def password_quality_policy(self) -> global___PasswordQualityPolicy:
        """Password quality policy for this userpool."""

    @property
    def password_lifetime_policy(self) -> global___PasswordLifetimePolicy:
        """Password lifetime policy for this userpool."""

    @property
    def bruteforce_protection_policy(self) -> global___BruteforceProtectionPolicy:
        """Bruteforce protection policy for this userpool."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        organization_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        domains: collections.abc.Iterable[builtins.str] | None = ...,
        status: global___Userpool.Status.ValueType = ...,
        user_settings: global___UserSettings | None = ...,
        password_quality_policy: global___PasswordQualityPolicy | None = ...,
        password_lifetime_policy: global___PasswordLifetimePolicy | None = ...,
        bruteforce_protection_policy: global___BruteforceProtectionPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bruteforce_protection_policy", b"bruteforce_protection_policy", "created_at", b"created_at", "password_lifetime_policy", b"password_lifetime_policy", "password_quality_policy", b"password_quality_policy", "updated_at", b"updated_at", "user_settings", b"user_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bruteforce_protection_policy", b"bruteforce_protection_policy", "created_at", b"created_at", "description", b"description", "domains", b"domains", "id", b"id", "labels", b"labels", "name", b"name", "organization_id", b"organization_id", "password_lifetime_policy", b"password_lifetime_policy", "password_quality_policy", b"password_quality_policy", "status", b"status", "updated_at", b"updated_at", "user_settings", b"user_settings"]) -> None: ...

global___Userpool = Userpool

@typing.final
class UserSettings(google.protobuf.message.Message):
    """Settings that control user capabilities within a userpool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_EDIT_SELF_PASSWORD_FIELD_NUMBER: builtins.int
    ALLOW_EDIT_SELF_INFO_FIELD_NUMBER: builtins.int
    ALLOW_EDIT_SELF_CONTACTS_FIELD_NUMBER: builtins.int
    ALLOW_EDIT_SELF_LOGIN_FIELD_NUMBER: builtins.int
    allow_edit_self_password: builtins.bool
    """Whether users can change their own passwords."""
    allow_edit_self_info: builtins.bool
    """Whether users can edit their own profile information."""
    allow_edit_self_contacts: builtins.bool
    """Whether users can edit their own contact information."""
    allow_edit_self_login: builtins.bool
    """Whether users can edit their own login information."""
    def __init__(
        self,
        *,
        allow_edit_self_password: builtins.bool = ...,
        allow_edit_self_info: builtins.bool = ...,
        allow_edit_self_contacts: builtins.bool = ...,
        allow_edit_self_login: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["allow_edit_self_contacts", b"allow_edit_self_contacts", "allow_edit_self_info", b"allow_edit_self_info", "allow_edit_self_login", b"allow_edit_self_login", "allow_edit_self_password", b"allow_edit_self_password"]) -> None: ...

global___UserSettings = UserSettings

@typing.final
class Domain(google.protobuf.message.Message):
    """A domain associated with a userpool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Domain._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Domain._Status.ValueType  # 0
        """The status is not specified."""
        NEED_TO_VALIDATE: Domain._Status.ValueType  # 1
        """The domain needs to be validated."""
        VALIDATING: Domain._Status.ValueType  # 2
        """The domain is in the process of being validated."""
        VALID: Domain._Status.ValueType  # 3
        """The domain has been successfully validated."""
        INVALID: Domain._Status.ValueType  # 4
        """The domain validation has failed."""
        DELETING: Domain._Status.ValueType  # 5
        """The domain is in the process of being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Represents the current status of a domain."""

    STATUS_UNSPECIFIED: Domain.Status.ValueType  # 0
    """The status is not specified."""
    NEED_TO_VALIDATE: Domain.Status.ValueType  # 1
    """The domain needs to be validated."""
    VALIDATING: Domain.Status.ValueType  # 2
    """The domain is in the process of being validated."""
    VALID: Domain.Status.ValueType  # 3
    """The domain has been successfully validated."""
    INVALID: Domain.Status.ValueType  # 4
    """The domain validation has failed."""
    DELETING: Domain.Status.ValueType  # 5
    """The domain is in the process of being deleted."""

    DOMAIN_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    STATUS_CODE_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    VALIDATED_AT_FIELD_NUMBER: builtins.int
    CHALLENGES_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    domain: builtins.str
    """Domain name."""
    status: global___Domain.Status.ValueType
    """Current status of the domain."""
    status_code: builtins.str
    """Optional code providing details about validation errors."""
    deletion_protection: builtins.bool
    """Whether the domain is protected from deletion."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the domain was created."""

    @property
    def validated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the domain was validated."""

    @property
    def challenges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DomainChallenge]:
        """List of challenges associated with this domain."""

    def __init__(
        self,
        *,
        domain: builtins.str = ...,
        status: global___Domain.Status.ValueType = ...,
        status_code: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        validated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        challenges: collections.abc.Iterable[global___DomainChallenge] | None = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "validated_at", b"validated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["challenges", b"challenges", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "domain", b"domain", "status", b"status", "status_code", b"status_code", "validated_at", b"validated_at"]) -> None: ...

global___Domain = Domain

@typing.final
class DomainChallenge(google.protobuf.message.Message):
    """A challenge used to validate domain ownership."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DomainChallenge._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: DomainChallenge._Type.ValueType  # 0
        """The type is not specified."""
        DNS_TXT: DomainChallenge._Type.ValueType  # 1
        """DNS TXT record challenge."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper):
        """Type of domain challenge."""

    TYPE_UNSPECIFIED: DomainChallenge.Type.ValueType  # 0
    """The type is not specified."""
    DNS_TXT: DomainChallenge.Type.ValueType  # 1
    """DNS TXT record challenge."""

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DomainChallenge._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: DomainChallenge._Status.ValueType  # 0
        """The status is not specified."""
        PENDING: DomainChallenge._Status.ValueType  # 1
        """The challenge is pending verification."""
        PROCESSING: DomainChallenge._Status.ValueType  # 2
        """The challenge verification is in progress."""
        VALID: DomainChallenge._Status.ValueType  # 3
        """The challenge has been successfully verified."""
        INVALID: DomainChallenge._Status.ValueType  # 4
        """The challenge verification has failed."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Status of the domain challenge."""

    STATUS_UNSPECIFIED: DomainChallenge.Status.ValueType  # 0
    """The status is not specified."""
    PENDING: DomainChallenge.Status.ValueType  # 1
    """The challenge is pending verification."""
    PROCESSING: DomainChallenge.Status.ValueType  # 2
    """The challenge verification is in progress."""
    VALID: DomainChallenge.Status.ValueType  # 3
    """The challenge has been successfully verified."""
    INVALID: DomainChallenge.Status.ValueType  # 4
    """The challenge verification has failed."""

    @typing.final
    class DnsRecord(google.protobuf.message.Message):
        """DNS record information for domain validation."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Type:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DomainChallenge.DnsRecord._Type.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            TYPE_UNSPECIFIED: DomainChallenge.DnsRecord._Type.ValueType  # 0
            """The type is not specified."""
            TXT: DomainChallenge.DnsRecord._Type.ValueType  # 1
            """TXT record type."""

        class Type(_Type, metaclass=_TypeEnumTypeWrapper):
            """Type of DNS record."""

        TYPE_UNSPECIFIED: DomainChallenge.DnsRecord.Type.ValueType  # 0
        """The type is not specified."""
        TXT: DomainChallenge.DnsRecord.Type.ValueType  # 1
        """TXT record type."""

        NAME_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Name of the DNS record."""
        type: global___DomainChallenge.DnsRecord.Type.ValueType
        """Type of the DNS record."""
        value: builtins.str
        """Value of the DNS record."""
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            type: global___DomainChallenge.DnsRecord.Type.ValueType = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["name", b"name", "type", b"type", "value", b"value"]) -> None: ...

    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DNS_CHALLENGE_FIELD_NUMBER: builtins.int
    type: global___DomainChallenge.Type.ValueType
    """Type of the challenge."""
    status: global___DomainChallenge.Status.ValueType
    """Current status of the challenge."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the challenge was created."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the challenge was last updated."""

    @property
    def dns_challenge(self) -> global___DomainChallenge.DnsRecord:
        """DNS record challenge details."""

    def __init__(
        self,
        *,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        type: global___DomainChallenge.Type.ValueType = ...,
        status: global___DomainChallenge.Status.ValueType = ...,
        dns_challenge: global___DomainChallenge.DnsRecord | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["challenge", b"challenge", "created_at", b"created_at", "dns_challenge", b"dns_challenge", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["challenge", b"challenge", "created_at", b"created_at", "dns_challenge", b"dns_challenge", "status", b"status", "type", b"type", "updated_at", b"updated_at"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["challenge", b"challenge"]) -> typing.Literal["dns_challenge"] | None: ...

global___DomainChallenge = DomainChallenge

@typing.final
class PasswordQualityPolicy(google.protobuf.message.Message):
    """Policy that defines password quality requirements."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class RequiredClasses(google.protobuf.message.Message):
        """Character classes that can be required in passwords."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LOWERS_FIELD_NUMBER: builtins.int
        UPPERS_FIELD_NUMBER: builtins.int
        DIGITS_FIELD_NUMBER: builtins.int
        SPECIALS_FIELD_NUMBER: builtins.int
        lowers: builtins.bool
        """Whether lowercase letters are required."""
        uppers: builtins.bool
        """Whether uppercase letters are required."""
        digits: builtins.bool
        """Whether digits are required."""
        specials: builtins.bool
        """Whether special characters are required."""
        def __init__(
            self,
            *,
            lowers: builtins.bool = ...,
            uppers: builtins.bool = ...,
            digits: builtins.bool = ...,
            specials: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["digits", b"digits", "lowers", b"lowers", "specials", b"specials", "uppers", b"uppers"]) -> None: ...

    @typing.final
    class MinLengthByClassSettings(google.protobuf.message.Message):
        """Minimum password length requirements based on character class diversity."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ONE_FIELD_NUMBER: builtins.int
        TWO_FIELD_NUMBER: builtins.int
        THREE_FIELD_NUMBER: builtins.int
        one: builtins.int
        """Minimum length for passwords with one character class."""
        two: builtins.int
        """Minimum length for passwords with two character classes."""
        three: builtins.int
        """Minimum length for passwords with three character classes."""
        def __init__(
            self,
            *,
            one: builtins.int = ...,
            two: builtins.int = ...,
            three: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["one", b"one", "three", b"three", "two", b"two"]) -> None: ...

    ALLOW_SIMILAR_FIELD_NUMBER: builtins.int
    MAX_LENGTH_FIELD_NUMBER: builtins.int
    MIN_LENGTH_FIELD_NUMBER: builtins.int
    MATCH_LENGTH_FIELD_NUMBER: builtins.int
    REQUIRED_CLASSES_FIELD_NUMBER: builtins.int
    MIN_LENGTH_BY_CLASS_SETTINGS_FIELD_NUMBER: builtins.int
    allow_similar: builtins.bool
    """Whether passwords similar to previous ones are allowed."""
    max_length: builtins.int
    """Maximum password length. Zero means no maximum length is enforced."""
    min_length: builtins.int
    """Minimum password length."""
    match_length: builtins.int
    """Minimum length of substrings to check for similarity to vulnerable sequences."""
    @property
    def required_classes(self) -> global___PasswordQualityPolicy.RequiredClasses:
        """Character classes required in passwords."""

    @property
    def min_length_by_class_settings(self) -> global___PasswordQualityPolicy.MinLengthByClassSettings:
        """Minimum length requirements based on character class diversity.
        If not specified, these checks are disabled.
        """

    def __init__(
        self,
        *,
        allow_similar: builtins.bool = ...,
        max_length: builtins.int = ...,
        min_length: builtins.int = ...,
        match_length: builtins.int = ...,
        required_classes: global___PasswordQualityPolicy.RequiredClasses | None = ...,
        min_length_by_class_settings: global___PasswordQualityPolicy.MinLengthByClassSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["min_length_by_class_settings", b"min_length_by_class_settings", "required_classes", b"required_classes"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allow_similar", b"allow_similar", "match_length", b"match_length", "max_length", b"max_length", "min_length", b"min_length", "min_length_by_class_settings", b"min_length_by_class_settings", "required_classes", b"required_classes"]) -> None: ...

global___PasswordQualityPolicy = PasswordQualityPolicy

@typing.final
class PasswordLifetimePolicy(google.protobuf.message.Message):
    """Policy that defines password lifetime requirements."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_DAYS_COUNT_FIELD_NUMBER: builtins.int
    MAX_DAYS_COUNT_FIELD_NUMBER: builtins.int
    min_days_count: builtins.int
    """Minimum number of days before a password can be changed."""
    max_days_count: builtins.int
    """Maximum number of days a password remains valid.
    Zero means passwords never expire.
    """
    def __init__(
        self,
        *,
        min_days_count: builtins.int = ...,
        max_days_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["max_days_count", b"max_days_count", "min_days_count", b"min_days_count"]) -> None: ...

global___PasswordLifetimePolicy = PasswordLifetimePolicy

@typing.final
class BruteforceProtectionPolicy(google.protobuf.message.Message):
    """Policy that defines protection against brute force attacks."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WINDOW_FIELD_NUMBER: builtins.int
    BLOCK_FIELD_NUMBER: builtins.int
    ATTEMPTS_FIELD_NUMBER: builtins.int
    attempts: builtins.int
    """Number of failed attempts allowed within the window before blocking."""
    @property
    def window(self) -> google.protobuf.duration_pb2.Duration:
        """Time window for counting failed authentication attempts."""

    @property
    def block(self) -> google.protobuf.duration_pb2.Duration:
        """Duration of the block after too many failed attempts."""

    def __init__(
        self,
        *,
        window: google.protobuf.duration_pb2.Duration | None = ...,
        block: google.protobuf.duration_pb2.Duration | None = ...,
        attempts: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["block", b"block", "window", b"window"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attempts", b"attempts", "block", b"block", "window", b"window"]) -> None: ...

global___BruteforceProtectionPolicy = BruteforceProtectionPolicy



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.elasticsearch.v1.user_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Elasticsearch cluster the user belongs to.

    To get the cluster ID, make a [ClusterService.List] request.
    """
    user_name: builtins.str
    """Name of the Elasticsearch user to return.

    To get the name of the user, make a [UserService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___GetUserRequest = GetUserRequest

@typing.final
class ListUsersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Elasticsearch cluster to list Elasticsearch users in.

    To get the cluster ID, use a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return.

    If the number of available results is larger than `page_size`, the service returns a [ListUsersResponse.next_page_token] that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token.

    To get the next page of results, set `page_token` to the [ListUsersResponse.next_page_token] returned by the previous list request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListUsersRequest = ListUsersRequest

@typing.final
class ListUsersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests.

    If the number of results is larger than [ListUsersRequest.page_size], use the `next_page_token` as the value for the [ListUsersRequest.page_token] parameter in the next list request.
    Each subsequent list request will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.elasticsearch.v1.user_pb2.User]:
        """List of Elasticsearch users."""

    def __init__(
        self,
        *,
        users: collections.abc.Iterable[yandex.cloud.mdb.elasticsearch.v1.user_pb2.User] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "users", b"users"]) -> None: ...

global___ListUsersResponse = ListUsersResponse

@typing.final
class CreateUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Elasticsearch cluster to create a user in.

    To get the cluster ID, make a [ClusterService.List] request.
    """
    @property
    def user_spec(self) -> yandex.cloud.mdb.elasticsearch.v1.user_pb2.UserSpec:
        """Configuration of the user to create."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_spec: yandex.cloud.mdb.elasticsearch.v1.user_pb2.UserSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["user_spec", b"user_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_spec", b"user_spec"]) -> None: ...

global___CreateUserRequest = CreateUserRequest

@typing.final
class CreateUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Elasticsearch cluster the user is being created in."""
    user_name: builtins.str
    """Name of the user that is being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___CreateUserMetadata = CreateUserMetadata

@typing.final
class UpdateUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Elasticsearch cluster the user belongs to.

    To get the cluster ID, make a [ClusterService.List] request.
    """
    user_name: builtins.str
    """Name of the user to be updated.

    To get the name of the user, make a [UserService.List] request.
    """
    password: builtins.str
    """New password for the user."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        password: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "password", b"password", "update_mask", b"update_mask", "user_name", b"user_name"]) -> None: ...

global___UpdateUserRequest = UpdateUserRequest

@typing.final
class UpdateUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Elasticsearch cluster the user belongs to."""
    user_name: builtins.str
    """Name of the user that is being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___UpdateUserMetadata = UpdateUserMetadata

@typing.final
class DeleteUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Elasticsearch cluster the user belongs to.

    To get the cluster ID, make a [ClusterService.List] request.
    """
    user_name: builtins.str
    """Name of the user to delete.

    To get the name of the user, make a [UserService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___DeleteUserRequest = DeleteUserRequest

@typing.final
class DeleteUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Elasticsearch cluster the user belongs to."""
    user_name: builtins.str
    """Name of the user that is being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___DeleteUserMetadata = DeleteUserMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/datasphere/v2/dataset_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/datasphere/v2/dataset_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/datasphere/v2/dataset_service.proto\x12\x1ayandex.cloud.datasphere.v2\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"\\\n\x16\x41\x63tivateDatasetRequest\x12 \n\ndataset_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\nproject_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"^\n\x18\x44\x65\x61\x63tivateDatasetRequest\x12 \n\ndataset_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\nproject_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=502\xec\x02\n\x0e\x44\x61tasetService\x12\xa8\x01\n\x08\x41\x63tivate\x12\x32.yandex.cloud.datasphere.v2.ActivateDatasetRequest\x1a!.yandex.cloud.operation.Operation\"E\xb2\xd2*\x17\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02$\"\x1f/datasphere/v2/dataset/activate:\x01*\x12\xae\x01\n\nDeactivate\x12\x34.yandex.cloud.datasphere.v2.DeactivateDatasetRequest\x1a!.yandex.cloud.operation.Operation\"G\xb2\xd2*\x17\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02&\"!/datasphere/v2/dataset/deactivate:\x01*Bk\n\x1eyandex.cloud.api.datasphere.v2ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v2.dataset_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.datasphere.v2ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphere'
  _globals['_ACTIVATEDATASETREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_ACTIVATEDATASETREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ACTIVATEDATASETREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_ACTIVATEDATASETREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DEACTIVATEDATASETREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_DEACTIVATEDATASETREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DEACTIVATEDATASETREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_DEACTIVATEDATASETREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DATASETSERVICE'].methods_by_name['Activate']._loaded_options = None
  _globals['_DATASETSERVICE'].methods_by_name['Activate']._serialized_options = b'\262\322*\027\022\025google.protobuf.Empty\202\323\344\223\002$\"\037/datasphere/v2/dataset/activate:\001*'
  _globals['_DATASETSERVICE'].methods_by_name['Deactivate']._loaded_options = None
  _globals['_DATASETSERVICE'].methods_by_name['Deactivate']._serialized_options = b'\262\322*\027\022\025google.protobuf.Empty\202\323\344\223\002&\"!/datasphere/v2/dataset/deactivate:\001*'
  _globals['_ACTIVATEDATASETREQUEST']._serialized_start=215
  _globals['_ACTIVATEDATASETREQUEST']._serialized_end=307
  _globals['_DEACTIVATEDATASETREQUEST']._serialized_start=309
  _globals['_DEACTIVATEDATASETREQUEST']._serialized_end=403
  _globals['_DATASETSERVICE']._serialized_start=406
  _globals['_DATASETSERVICE']._serialized_end=770
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/mongodb/v1/config/mongodb.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/mongodb/v1/config/mongodb.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/mdb/mongodb/v1/config/mongodb.proto\x12\"yandex.cloud.mdb.mongodb.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\x87\x1e\n\x0cMongodConfig\x12I\n\x07storage\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.mdb.mongodb.v1.config.MongodConfig.Storage\x12`\n\x13operation_profiling\x18\x02 \x01(\x0b\x32\x43.yandex.cloud.mdb.mongodb.v1.config.MongodConfig.OperationProfiling\x12\x45\n\x03net\x18\x03 \x01(\x0b\x32\x38.yandex.cloud.mdb.mongodb.v1.config.MongodConfig.Network\x12K\n\x08security\x18\x04 \x01(\x0b\x32\x39.yandex.cloud.mdb.mongodb.v1.config.MongodConfig.Security\x12L\n\taudit_log\x18\x05 \x01(\x0b\x32\x39.yandex.cloud.mdb.mongodb.v1.config.MongodConfig.AuditLog\x12T\n\rset_parameter\x18\x06 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.config.MongodConfig.SetParameter\x12\x45\n\x05oplog\x18\x07 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.config.MongodConfig.Oplog\x1a\xf4\x07\n\x07Storage\x12X\n\x0bwired_tiger\x18\x01 \x01(\x0b\x32\x43.yandex.cloud.mdb.mongodb.v1.config.MongodConfig.Storage.WiredTiger\x12Q\n\x07journal\x18\x02 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.config.MongodConfig.Storage.Journal\x1a\xef\x05\n\nWiredTiger\x12g\n\rengine_config\x18\x01 \x01(\x0b\x32P.yandex.cloud.mdb.mongodb.v1.config.MongodConfig.Storage.WiredTiger.EngineConfig\x12o\n\x11\x63ollection_config\x18\x02 \x01(\x0b\x32T.yandex.cloud.mdb.mongodb.v1.config.MongodConfig.Storage.WiredTiger.CollectionConfig\x12\x65\n\x0cindex_config\x18\x03 \x01(\x0b\x32O.yandex.cloud.mdb.mongodb.v1.config.MongodConfig.Storage.WiredTiger.IndexConfig\x1au\n\x0c\x45ngineConfig\x12\x33\n\rcache_size_gb\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x30\n\ncache_size\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a\xe1\x01\n\x10\x43ollectionConfig\x12y\n\x10\x62lock_compressor\x18\x01 \x01(\x0e\x32_.yandex.cloud.mdb.mongodb.v1.config.MongodConfig.Storage.WiredTiger.CollectionConfig.Compressor\"R\n\nCompressor\x12\x1a\n\x16\x43OMPRESSOR_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\n\n\x06SNAPPY\x10\x02\x12\x08\n\x04ZLIB\x10\x03\x12\x08\n\x04ZSTD\x10\x04\x1a\x45\n\x0bIndexConfig\x12\x36\n\x12prefix_compression\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1aJ\n\x07Journal\x12?\n\x0f\x63ommit_interval\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x31-500\x1a\xad\x02\n\x12OperationProfiling\x12V\n\x04mode\x18\x01 \x01(\x0e\x32H.yandex.cloud.mdb.mongodb.v1.config.MongodConfig.OperationProfiling.Mode\x12>\n\x11slow_op_threshold\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x42\n\x13slow_op_sample_rate\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x07\xfa\xc7\x31\x03\x30-1\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x07\n\x03OFF\x10\x01\x12\x0b\n\x07SLOW_OP\x10\x02\x12\x07\n\x03\x41LL\x10\x03\x1a\x88\x03\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\x12Y\n\x0b\x63ompression\x18\x02 \x01(\x0b\x32\x44.yandex.cloud.mdb.mongodb.v1.config.MongodConfig.Network.Compression\x1a\xd4\x01\n\x0b\x43ompression\x12m\n\x0b\x63ompressors\x18\x01 \x03(\x0e\x32O.yandex.cloud.mdb.mongodb.v1.config.MongodConfig.Network.Compression.CompressorB\x07\x82\xc8\x31\x03\x31-3\"V\n\nCompressor\x12\x1a\n\x16\x43OMPRESSOR_UNSPECIFIED\x10\x00\x12\n\n\x06SNAPPY\x10\x01\x12\x08\n\x04ZLIB\x10\x02\x12\x08\n\x04ZSTD\x10\x03\x12\x0c\n\x08\x44ISABLED\x10\x04\x1a\x9f\x02\n\x08Security\x12\x35\n\x11\x65nable_encryption\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12L\n\x04kmip\x18\x02 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongodConfig.Security.KMIP\x1a\x8d\x01\n\x04KMIP\x12\x13\n\x0bserver_name\x18\x01 \x01(\t\x12)\n\x04port\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x11\n\tserver_ca\x18\x03 \x01(\t\x12\x1a\n\x12\x63lient_certificate\x18\x04 \x01(\t\x12\x16\n\x0ekey_identifier\x18\x05 \x01(\t\x1aU\n\x08\x41uditLog\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t\x12\x39\n\x15runtime_configuration\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\xa4\x08\n\x0cSetParameter\x12?\n\x1b\x61udit_authorization_success\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x13\x65nable_flow_control\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12T\n&min_snapshot_history_window_in_seconds\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12L\n\x1f\x66low_control_target_lag_seconds\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12Q\n#flow_control_warn_threshold_seconds\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12T\n&migrate_clone_insertion_batch_delay_ms\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12P\n\"migrate_clone_insertion_batch_size\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12>\n\x19orphan_cleanup_delay_secs\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12P\n+persisted_chunk_cache_update_max_batch_size\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12J\n\x1crange_deleter_batch_delay_ms\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x46\n\x18range_deleter_batch_size\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12_\n\x0cmirror_reads\x18\x0c \x01(\x0b\x32I.yandex.cloud.mdb.mongodb.v1.config.MongodConfig.SetParameter.MirrorReads\x1at\n\x0bMirrorReads\x12\x33\n\rsampling_rate\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x30\n\x0bmax_time_ms\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1ay\n\x05Oplog\x12\x35\n\x10max_size_percent\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x13min_retention_hours\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"\xa3\x0f\n\x0eMongoCfgConfig\x12K\n\x07storage\x18\x01 \x01(\x0b\x32:.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig.Storage\x12\x62\n\x13operation_profiling\x18\x02 \x01(\x0b\x32\x45.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig.OperationProfiling\x12G\n\x03net\x18\x03 \x01(\x0b\x32:.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig.Network\x12V\n\rset_parameter\x18\x04 \x01(\x0b\x32?.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig.SetParameter\x12N\n\taudit_log\x18\x05 \x01(\x0b\x32;.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig.AuditLog\x12G\n\x05oplog\x18\x06 \x01(\x0b\x32\x38.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig.Oplog\x1a\x86\x04\n\x07Storage\x12Z\n\x0bwired_tiger\x18\x01 \x01(\x0b\x32\x45.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig.Storage.WiredTiger\x1a\x9e\x03\n\nWiredTiger\x12i\n\rengine_config\x18\x01 \x01(\x0b\x32R.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig.Storage.WiredTiger.EngineConfig\x12g\n\x0cindex_config\x18\x02 \x01(\x0b\x32Q.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig.Storage.WiredTiger.IndexConfig\x1au\n\x0c\x45ngineConfig\x12\x33\n\rcache_size_gb\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x30\n\ncache_size\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a\x45\n\x0bIndexConfig\x12\x36\n\x12prefix_compression\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\xeb\x01\n\x12OperationProfiling\x12X\n\x04mode\x18\x01 \x01(\x0e\x32J.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig.OperationProfiling.Mode\x12>\n\x11slow_op_threshold\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x07\n\x03OFF\x10\x01\x12\x0b\n\x07SLOW_OP\x10\x02\x12\x07\n\x03\x41LL\x10\x03\x1a\x8c\x03\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\x12[\n\x0b\x63ompression\x18\x02 \x01(\x0b\x32\x46.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig.Network.Compression\x1a\xd6\x01\n\x0b\x43ompression\x12o\n\x0b\x63ompressors\x18\x01 \x03(\x0e\x32Q.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig.Network.Compression.CompressorB\x07\x82\xc8\x31\x03\x31-3\"V\n\nCompressor\x12\x1a\n\x16\x43OMPRESSOR_UNSPECIFIED\x10\x00\x12\n\n\x06SNAPPY\x10\x01\x12\x08\n\x04ZLIB\x10\x02\x12\x08\n\x04ZSTD\x10\x03\x12\x0c\n\x08\x44ISABLED\x10\x04\x1a\x88\x01\n\x0cSetParameter\x12\x37\n\x13\x65nable_flow_control\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x1b\x61udit_authorization_success\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\x1a\n\x08\x41uditLog\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t\x1ay\n\x05Oplog\x12\x35\n\x10max_size_percent\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x13min_retention_hours\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"\xa8\x0e\n\x0cMongosConfig\x12\x45\n\x03net\x18\x03 \x01(\x0b\x32\x38.yandex.cloud.mdb.mongodb.v1.config.MongosConfig.Network\x12T\n\rset_parameter\x18\x04 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.config.MongosConfig.SetParameter\x12L\n\taudit_log\x18\x05 \x01(\x0b\x32\x39.yandex.cloud.mdb.mongodb.v1.config.MongosConfig.AuditLog\x12/\n\nchunk_size\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1a\x88\x03\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\x12Y\n\x0b\x63ompression\x18\x02 \x01(\x0b\x32\x44.yandex.cloud.mdb.mongodb.v1.config.MongosConfig.Network.Compression\x1a\xd4\x01\n\x0b\x43ompression\x12m\n\x0b\x63ompressors\x18\x01 \x03(\x0e\x32O.yandex.cloud.mdb.mongodb.v1.config.MongosConfig.Network.Compression.CompressorB\x07\x82\xc8\x31\x03\x31-3\"V\n\nCompressor\x12\x1a\n\x16\x43OMPRESSOR_UNSPECIFIED\x10\x00\x12\n\n\x06SNAPPY\x10\x01\x12\x08\n\x04ZLIB\x10\x02\x12\x08\n\x04ZSTD\x10\x03\x12\x0c\n\x08\x44ISABLED\x10\x04\x1a\xd4\x08\n\x0cSetParameter\x12?\n\x1b\x61udit_authorization_success\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x11read_hedging_mode\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12I\n$sharding_task_executor_pool_max_size\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12O\n*sharding_task_executor_pool_max_connecting\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12I\n$sharding_task_executor_pool_min_size\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12V\n0sharding_task_executor_pool_replica_set_matching\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12P\n+sharding_task_executor_pool_host_timeout_ms\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12W\n2sharding_task_executor_pool_refresh_requirement_ms\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12S\n.sharding_task_executor_pool_refresh_timeout_ms\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x62\n>warm_min_connections_in_sharding_task_executor_pool_on_startup\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12k\nFwarm_min_connections_in_sharding_task_executor_pool_on_startup_wait_ms\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\\\n7sharding_task_executor_pool_max_size_for_config_servers\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\\\n7sharding_task_executor_pool_min_size_for_config_servers\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1a\x1a\n\x08\x41uditLog\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t\"\xee\x01\n\x0fMongodConfigSet\x12J\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.config.MongodConfig\x12\x45\n\x0buser_config\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.config.MongodConfig\x12H\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.config.MongodConfig\"\xf6\x01\n\x11MongoCfgConfigSet\x12L\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig\x12G\n\x0buser_config\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig\x12J\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig\"\xee\x01\n\x0fMongosConfigSet\x12J\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.config.MongosConfig\x12\x45\n\x0buser_config\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.config.MongosConfig\x12H\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.config.MongosConfigBx\n&yandex.cloud.api.mdb.mongodb.v1.configZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1/config;mongodbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.mongodb.v1.config.mongodb_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&yandex.cloud.api.mdb.mongodb.v1.configZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1/config;mongodb'
  _globals['_MONGODCONFIG_STORAGE_JOURNAL'].fields_by_name['commit_interval']._loaded_options = None
  _globals['_MONGODCONFIG_STORAGE_JOURNAL'].fields_by_name['commit_interval']._serialized_options = b'\372\3071\0051-500'
  _globals['_MONGODCONFIG_OPERATIONPROFILING'].fields_by_name['slow_op_threshold']._loaded_options = None
  _globals['_MONGODCONFIG_OPERATIONPROFILING'].fields_by_name['slow_op_threshold']._serialized_options = b'\372\3071\002>0'
  _globals['_MONGODCONFIG_OPERATIONPROFILING'].fields_by_name['slow_op_sample_rate']._loaded_options = None
  _globals['_MONGODCONFIG_OPERATIONPROFILING'].fields_by_name['slow_op_sample_rate']._serialized_options = b'\372\3071\0030-1'
  _globals['_MONGODCONFIG_NETWORK_COMPRESSION'].fields_by_name['compressors']._loaded_options = None
  _globals['_MONGODCONFIG_NETWORK_COMPRESSION'].fields_by_name['compressors']._serialized_options = b'\202\3101\0031-3'
  _globals['_MONGODCONFIG_NETWORK'].fields_by_name['max_incoming_connections']._loaded_options = None
  _globals['_MONGODCONFIG_NETWORK'].fields_by_name['max_incoming_connections']._serialized_options = b'\372\3071\01010-16384'
  _globals['_MONGODCONFIG_SETPARAMETER'].fields_by_name['min_snapshot_history_window_in_seconds']._loaded_options = None
  _globals['_MONGODCONFIG_SETPARAMETER'].fields_by_name['min_snapshot_history_window_in_seconds']._serialized_options = b'\372\3071\003>=0'
  _globals['_MONGODCONFIG_SETPARAMETER'].fields_by_name['flow_control_target_lag_seconds']._loaded_options = None
  _globals['_MONGODCONFIG_SETPARAMETER'].fields_by_name['flow_control_target_lag_seconds']._serialized_options = b'\372\3071\002>0'
  _globals['_MONGODCONFIG_SETPARAMETER'].fields_by_name['flow_control_warn_threshold_seconds']._loaded_options = None
  _globals['_MONGODCONFIG_SETPARAMETER'].fields_by_name['flow_control_warn_threshold_seconds']._serialized_options = b'\372\3071\003>=0'
  _globals['_MONGODCONFIG_SETPARAMETER'].fields_by_name['migrate_clone_insertion_batch_delay_ms']._loaded_options = None
  _globals['_MONGODCONFIG_SETPARAMETER'].fields_by_name['migrate_clone_insertion_batch_delay_ms']._serialized_options = b'\372\3071\003>=0'
  _globals['_MONGODCONFIG_SETPARAMETER'].fields_by_name['migrate_clone_insertion_batch_size']._loaded_options = None
  _globals['_MONGODCONFIG_SETPARAMETER'].fields_by_name['migrate_clone_insertion_batch_size']._serialized_options = b'\372\3071\003>=0'
  _globals['_MONGODCONFIG_SETPARAMETER'].fields_by_name['range_deleter_batch_delay_ms']._loaded_options = None
  _globals['_MONGODCONFIG_SETPARAMETER'].fields_by_name['range_deleter_batch_delay_ms']._serialized_options = b'\372\3071\003>=0'
  _globals['_MONGODCONFIG_SETPARAMETER'].fields_by_name['range_deleter_batch_size']._loaded_options = None
  _globals['_MONGODCONFIG_SETPARAMETER'].fields_by_name['range_deleter_batch_size']._serialized_options = b'\372\3071\003>=0'
  _globals['_MONGOCFGCONFIG_OPERATIONPROFILING'].fields_by_name['slow_op_threshold']._loaded_options = None
  _globals['_MONGOCFGCONFIG_OPERATIONPROFILING'].fields_by_name['slow_op_threshold']._serialized_options = b'\372\3071\002>0'
  _globals['_MONGOCFGCONFIG_NETWORK_COMPRESSION'].fields_by_name['compressors']._loaded_options = None
  _globals['_MONGOCFGCONFIG_NETWORK_COMPRESSION'].fields_by_name['compressors']._serialized_options = b'\202\3101\0031-3'
  _globals['_MONGOCFGCONFIG_NETWORK'].fields_by_name['max_incoming_connections']._loaded_options = None
  _globals['_MONGOCFGCONFIG_NETWORK'].fields_by_name['max_incoming_connections']._serialized_options = b'\372\3071\01010-16384'
  _globals['_MONGOSCONFIG_NETWORK_COMPRESSION'].fields_by_name['compressors']._loaded_options = None
  _globals['_MONGOSCONFIG_NETWORK_COMPRESSION'].fields_by_name['compressors']._serialized_options = b'\202\3101\0031-3'
  _globals['_MONGOSCONFIG_NETWORK'].fields_by_name['max_incoming_connections']._loaded_options = None
  _globals['_MONGOSCONFIG_NETWORK'].fields_by_name['max_incoming_connections']._serialized_options = b'\372\3071\01010-16384'
  _globals['_MONGODCONFIG']._serialized_start=152
  _globals['_MONGODCONFIG']._serialized_end=3999
  _globals['_MONGODCONFIG_STORAGE']._serialized_start=725
  _globals['_MONGODCONFIG_STORAGE']._serialized_end=1737
  _globals['_MONGODCONFIG_STORAGE_WIREDTIGER']._serialized_start=910
  _globals['_MONGODCONFIG_STORAGE_WIREDTIGER']._serialized_end=1661
  _globals['_MONGODCONFIG_STORAGE_WIREDTIGER_ENGINECONFIG']._serialized_start=1245
  _globals['_MONGODCONFIG_STORAGE_WIREDTIGER_ENGINECONFIG']._serialized_end=1362
  _globals['_MONGODCONFIG_STORAGE_WIREDTIGER_COLLECTIONCONFIG']._serialized_start=1365
  _globals['_MONGODCONFIG_STORAGE_WIREDTIGER_COLLECTIONCONFIG']._serialized_end=1590
  _globals['_MONGODCONFIG_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR']._serialized_start=1508
  _globals['_MONGODCONFIG_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR']._serialized_end=1590
  _globals['_MONGODCONFIG_STORAGE_WIREDTIGER_INDEXCONFIG']._serialized_start=1592
  _globals['_MONGODCONFIG_STORAGE_WIREDTIGER_INDEXCONFIG']._serialized_end=1661
  _globals['_MONGODCONFIG_STORAGE_JOURNAL']._serialized_start=1663
  _globals['_MONGODCONFIG_STORAGE_JOURNAL']._serialized_end=1737
  _globals['_MONGODCONFIG_OPERATIONPROFILING']._serialized_start=1740
  _globals['_MONGODCONFIG_OPERATIONPROFILING']._serialized_end=2041
  _globals['_MONGODCONFIG_OPERATIONPROFILING_MODE']._serialized_start=1982
  _globals['_MONGODCONFIG_OPERATIONPROFILING_MODE']._serialized_end=2041
  _globals['_MONGODCONFIG_NETWORK']._serialized_start=2044
  _globals['_MONGODCONFIG_NETWORK']._serialized_end=2436
  _globals['_MONGODCONFIG_NETWORK_COMPRESSION']._serialized_start=2224
  _globals['_MONGODCONFIG_NETWORK_COMPRESSION']._serialized_end=2436
  _globals['_MONGODCONFIG_NETWORK_COMPRESSION_COMPRESSOR']._serialized_start=2350
  _globals['_MONGODCONFIG_NETWORK_COMPRESSION_COMPRESSOR']._serialized_end=2436
  _globals['_MONGODCONFIG_SECURITY']._serialized_start=2439
  _globals['_MONGODCONFIG_SECURITY']._serialized_end=2726
  _globals['_MONGODCONFIG_SECURITY_KMIP']._serialized_start=2585
  _globals['_MONGODCONFIG_SECURITY_KMIP']._serialized_end=2726
  _globals['_MONGODCONFIG_AUDITLOG']._serialized_start=2728
  _globals['_MONGODCONFIG_AUDITLOG']._serialized_end=2813
  _globals['_MONGODCONFIG_SETPARAMETER']._serialized_start=2816
  _globals['_MONGODCONFIG_SETPARAMETER']._serialized_end=3876
  _globals['_MONGODCONFIG_SETPARAMETER_MIRRORREADS']._serialized_start=3760
  _globals['_MONGODCONFIG_SETPARAMETER_MIRRORREADS']._serialized_end=3876
  _globals['_MONGODCONFIG_OPLOG']._serialized_start=3878
  _globals['_MONGODCONFIG_OPLOG']._serialized_end=3999
  _globals['_MONGOCFGCONFIG']._serialized_start=4002
  _globals['_MONGOCFGCONFIG']._serialized_end=5957
  _globals['_MONGOCFGCONFIG_STORAGE']._serialized_start=4512
  _globals['_MONGOCFGCONFIG_STORAGE']._serialized_end=5030
  _globals['_MONGOCFGCONFIG_STORAGE_WIREDTIGER']._serialized_start=4616
  _globals['_MONGOCFGCONFIG_STORAGE_WIREDTIGER']._serialized_end=5030
  _globals['_MONGOCFGCONFIG_STORAGE_WIREDTIGER_ENGINECONFIG']._serialized_start=1245
  _globals['_MONGOCFGCONFIG_STORAGE_WIREDTIGER_ENGINECONFIG']._serialized_end=1362
  _globals['_MONGOCFGCONFIG_STORAGE_WIREDTIGER_INDEXCONFIG']._serialized_start=1592
  _globals['_MONGOCFGCONFIG_STORAGE_WIREDTIGER_INDEXCONFIG']._serialized_end=1661
  _globals['_MONGOCFGCONFIG_OPERATIONPROFILING']._serialized_start=5033
  _globals['_MONGOCFGCONFIG_OPERATIONPROFILING']._serialized_end=5268
  _globals['_MONGOCFGCONFIG_OPERATIONPROFILING_MODE']._serialized_start=1982
  _globals['_MONGOCFGCONFIG_OPERATIONPROFILING_MODE']._serialized_end=2041
  _globals['_MONGOCFGCONFIG_NETWORK']._serialized_start=5271
  _globals['_MONGOCFGCONFIG_NETWORK']._serialized_end=5667
  _globals['_MONGOCFGCONFIG_NETWORK_COMPRESSION']._serialized_start=5453
  _globals['_MONGOCFGCONFIG_NETWORK_COMPRESSION']._serialized_end=5667
  _globals['_MONGOCFGCONFIG_NETWORK_COMPRESSION_COMPRESSOR']._serialized_start=2350
  _globals['_MONGOCFGCONFIG_NETWORK_COMPRESSION_COMPRESSOR']._serialized_end=2436
  _globals['_MONGOCFGCONFIG_SETPARAMETER']._serialized_start=5670
  _globals['_MONGOCFGCONFIG_SETPARAMETER']._serialized_end=5806
  _globals['_MONGOCFGCONFIG_AUDITLOG']._serialized_start=2728
  _globals['_MONGOCFGCONFIG_AUDITLOG']._serialized_end=2754
  _globals['_MONGOCFGCONFIG_OPLOG']._serialized_start=3878
  _globals['_MONGOCFGCONFIG_OPLOG']._serialized_end=3999
  _globals['_MONGOSCONFIG']._serialized_start=5960
  _globals['_MONGOSCONFIG']._serialized_end=7792
  _globals['_MONGOSCONFIG_NETWORK']._serialized_start=6261
  _globals['_MONGOSCONFIG_NETWORK']._serialized_end=6653
  _globals['_MONGOSCONFIG_NETWORK_COMPRESSION']._serialized_start=6441
  _globals['_MONGOSCONFIG_NETWORK_COMPRESSION']._serialized_end=6653
  _globals['_MONGOSCONFIG_NETWORK_COMPRESSION_COMPRESSOR']._serialized_start=2350
  _globals['_MONGOSCONFIG_NETWORK_COMPRESSION_COMPRESSOR']._serialized_end=2436
  _globals['_MONGOSCONFIG_SETPARAMETER']._serialized_start=6656
  _globals['_MONGOSCONFIG_SETPARAMETER']._serialized_end=7764
  _globals['_MONGOSCONFIG_AUDITLOG']._serialized_start=2728
  _globals['_MONGOSCONFIG_AUDITLOG']._serialized_end=2754
  _globals['_MONGODCONFIGSET']._serialized_start=7795
  _globals['_MONGODCONFIGSET']._serialized_end=8033
  _globals['_MONGOCFGCONFIGSET']._serialized_start=8036
  _globals['_MONGOCFGCONFIGSET']._serialized_end=8282
  _globals['_MONGOSCONFIGSET']._serialized_start=8285
  _globals['_MONGOSCONFIGSET']._serialized_end=8523
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.idp.userpool_pb2
import yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class UserpoolServiceStub:
    """A set of methods for managing userpools."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.GetUserpoolRequest,
        yandex.cloud.organizationmanager.v1.idp.userpool_pb2.Userpool,
    ]
    """Returns the specified userpool.

    To get the list of available userpools, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolsRequest,
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolsResponse,
    ]
    """Retrieves the list of userpools in the specified organization."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.CreateUserpoolRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a userpool in the specified organization."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.UpdateUserpoolRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified userpool."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.DeleteUserpoolRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified userpool."""

    GetDomain: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.GetUserpoolDomainRequest,
        yandex.cloud.organizationmanager.v1.idp.userpool_pb2.Domain,
    ]
    """Returns the specified domain for a userpool."""

    ListDomains: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolDomainsRequest,
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolDomainsResponse,
    ]
    """Lists domains for the specified userpool."""

    AddDomain: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.AddUserpoolDomainRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds a domain to the specified userpool."""

    ValidateDomain: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ValidateUserpoolDomainRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Validates the specified domain for a userpool."""

    DeleteDomain: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.DeleteUserpoolDomainRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified domain from a userpool."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolOperationsRequest,
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolOperationsResponse,
    ]
    """Lists operations for the specified userpool."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists access bindings for the specified userpool."""

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified userpool."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified userpool."""

class UserpoolServiceAsyncStub:
    """A set of methods for managing userpools."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.GetUserpoolRequest,
        yandex.cloud.organizationmanager.v1.idp.userpool_pb2.Userpool,
    ]
    """Returns the specified userpool.

    To get the list of available userpools, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolsRequest,
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolsResponse,
    ]
    """Retrieves the list of userpools in the specified organization."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.CreateUserpoolRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a userpool in the specified organization."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.UpdateUserpoolRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified userpool."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.DeleteUserpoolRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified userpool."""

    GetDomain: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.GetUserpoolDomainRequest,
        yandex.cloud.organizationmanager.v1.idp.userpool_pb2.Domain,
    ]
    """Returns the specified domain for a userpool."""

    ListDomains: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolDomainsRequest,
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolDomainsResponse,
    ]
    """Lists domains for the specified userpool."""

    AddDomain: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.AddUserpoolDomainRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds a domain to the specified userpool."""

    ValidateDomain: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ValidateUserpoolDomainRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Validates the specified domain for a userpool."""

    DeleteDomain: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.DeleteUserpoolDomainRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified domain from a userpool."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolOperationsRequest,
        yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolOperationsResponse,
    ]
    """Lists operations for the specified userpool."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists access bindings for the specified userpool."""

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified userpool."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified userpool."""

class UserpoolServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing userpools."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.GetUserpoolRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.userpool_pb2.Userpool, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.userpool_pb2.Userpool]]:
        """Returns the specified userpool.

        To get the list of available userpools, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolsResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolsResponse]]:
        """Retrieves the list of userpools in the specified organization."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.CreateUserpoolRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a userpool in the specified organization."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.UpdateUserpoolRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified userpool."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.DeleteUserpoolRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified userpool."""

    @abc.abstractmethod
    def GetDomain(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.GetUserpoolDomainRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.userpool_pb2.Domain, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.userpool_pb2.Domain]]:
        """Returns the specified domain for a userpool."""

    @abc.abstractmethod
    def ListDomains(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolDomainsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolDomainsResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolDomainsResponse]]:
        """Lists domains for the specified userpool."""

    @abc.abstractmethod
    def AddDomain(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.AddUserpoolDomainRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds a domain to the specified userpool."""

    @abc.abstractmethod
    def ValidateDomain(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ValidateUserpoolDomainRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Validates the specified domain for a userpool."""

    @abc.abstractmethod
    def DeleteDomain(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.DeleteUserpoolDomainRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified domain from a userpool."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolOperationsResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2.ListUserpoolOperationsResponse]]:
        """Lists operations for the specified userpool."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """Lists access bindings for the specified userpool."""

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the specified userpool."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the specified userpool."""

def add_UserpoolServiceServicer_to_server(servicer: UserpoolServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
